@@ -1,17 +1,30 @@
 
 from functools import wraps
-from typing import Any, Callable, Optional, TypeVar
+from typing import TypeVar
 from finjet.container import Container
 
 
-def get_global_container() -> Optional[Container]:
+def set_global_container(container: Container) -> None:
+    """Set global container object
+
+    Returns
+    -------
+    Container
+        Container object
+    """
+    Container.current = container
+
+
+def get_global_container() -> Container:
     """get global container object
 
     Returns
     -------
-    Optional[Container]
+    Container
         Container object
     """
+    if Container.current is None:
+        Container.current = Container()
     return Container.current
 
 
@@ -23,12 +36,12 @@ def inject(func: T) -> T:
 
     Parameters
     ----------
-    func : Callable[[Any], Any]
+    func : T
         Any function or class.
 
     Returns
     -------
-    Callable[[Any], Any]
+    T
         func
     """
     @wraps(func)
